Index: third_party/freetype/include/freetype/ftbitmap.h |
diff --git a/third_party/freetype/include/ftbitmap.h b/third_party/freetype/include/freetype/ftbitmap.h |
similarity index 96% |
rename from third_party/freetype/include/ftbitmap.h |
rename to third_party/freetype/include/freetype/ftbitmap.h |
index eae716904b4420a4e06eec73d05ee2b5959e9c62..46cc47b7d1ed9f9ea6522def7fa2bae81a66db30 100644 |
--- a/third_party/freetype/include/ftbitmap.h |
+++ b/third_party/freetype/include/freetype/ftbitmap.h |
@@ -4,7 +4,7 @@ |
/* */ |
/* FreeType utility functions for bitmaps (specification). */ |
/* */ |
-/* Copyright 2004-2006, 2008, 2013, 2014 by */ |
+/* Copyright 2004-2015 by */ |
/* David Turner, Robert Wilhelm, and Werner Lemberg. */ |
/* */ |
/* This file is part of the FreeType project, and may only be used, */ |
@@ -55,7 +55,7 @@ FT_BEGIN_HEADER |
/*************************************************************************/ |
/* */ |
/* <Function> */ |
- /* FT_Bitmap_New */ |
+ /* FT_Bitmap_Init */ |
/* */ |
/* <Description> */ |
/* Initialize a pointer to an @FT_Bitmap structure. */ |
@@ -63,6 +63,14 @@ FT_BEGIN_HEADER |
/* <InOut> */ |
/* abitmap :: A pointer to the bitmap structure. */ |
/* */ |
+ /* <Note> */ |
+ /* A deprecated name for the same function is `FT_Bitmap_New'. */ |
+ /* */ |
+ FT_EXPORT( void ) |
+ FT_Bitmap_Init( FT_Bitmap *abitmap ); |
+ |
+ |
+ /* deprecated */ |
FT_EXPORT( void ) |
FT_Bitmap_New( FT_Bitmap *abitmap ); |
@@ -202,7 +210,7 @@ FT_BEGIN_HEADER |
/* FT_Bitmap_Done */ |
/* */ |
/* <Description> */ |
/* Destroy a bitmap object created with @FT_Bitmap_New. */ |
/* */ |
/* <Input> */ |
/* library :: A handle to a library object. */ |
@@ -202,7 +210,7 @@ FT_BEGIN_HEADER |
/* */ |
/* <Description> */ |
- /* Destroy a bitmap object created with @FT_Bitmap_New. */ |
+ /* Destroy a bitmap object initialized with @FT_Bitmap_Init. */ |
/* */ |
/* <Input> */ |